<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>التعاون</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>التعاون هو أداة مكتب قوية تعمل عبر واجهات متعددة تساعدك في نقل الملفات ومشاركة المفاتيح والماوس ومشاركة اللوحات بين الأجهزة المختلفة.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>إعدادات نقل الملفات</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>IP-locatie: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; stuurt enkele bestanden naar u</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Afwijzen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Accepteren</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Opnieuw proberen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Afwijzen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Accepteren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>Bekijk de Handleiding</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>Welkom bij dde-cooperation</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>Delen van toetsenbord en muis</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>Wanneer een verbinding wordt gemaakt tussen twee apparaten, kan het toetsenbord en de muis van de initiator worden gebruikt om het andere apparaat te controleren.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>Schermafdruk delen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>Zodra een verbinding wordt gemaakt tussen twee apparaten, wordt de schermafdruk gedeeld en kan deze worden gekopieerd op één apparaat en geplakt op het andere apparaat.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>Documenten leveren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>Na het verbinden van twee apparaten kunt u een bestandsoverdracht starten naar het andere apparaat.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>Voor gedetailleerde instructies, klik aub op de Handleiding hieronder.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>Gebruik</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>verbonden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>verbindbaar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>offline</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>Sluit</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>Klik aub om te bevestigen en de LAN-discovery-service in te schakelen!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>Niet in staat om apparaten te ontdekken en te worden ontdekt door andere apparaten wanneer de LAN-discovery-service niet is ingeschakeld</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>Niet in staat om apparaten te ontdekken en te worden ontdekt door andere apparaten wanneer de LAN-discovery-service niet is ingeschakeld. Klik met rechtermuisknop op het Windows Start-menu -&gt; Computerbeheer -&gt; Services en toepassingen -&gt; Services om de Bonjour-service in te schakelen</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>Eerste stap</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>De andere kant opent de toepassing en verbindt zich met hetzelfde netwerk</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>Tweede stap</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>Derde stap</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>om het bestand te verzenden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>om te verbinden met het peer-apparaat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>Typ het peer-IP-adres in het zoekvak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>de opslaglocatie van het bestand is ongeldig</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>Deze pad is een alleen-lezenmap. Kies aub een andere locatie voor het opslaan van het bestand.</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>Het huidige apparaat is vergrendeld</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>U kunt het vergrendelen op mobiele apparaten</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>Apparaten zoeken</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>Minimiseren naar systeemvak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>Geen meer vragen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>Selecteer aub uw bewerking</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>Telefoon</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>Selectie van leveringsapparaat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>Download client</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>Download Windows client</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>Verbind met het netwerk</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. Schakel kruis-end samenwerkingssoftware in. Toepassingen op UOS kunnen worden gedownload vanaf de App Store, en toepassingen op de Windows-kant kunnen worden gedownload vanaf: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>2. Op hetzelfde LAN als het apparaat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. Bestandsbeheer-Instellingen-File Drop-Stel de volgende gebruikers in om bestanden naar mij te laten werpen -&quot;Iedereen op hetzelfde LAN&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. Instellingen-Basisinstellingen-Discovery Modus-&quot;Sta iedereen op hetzelfde LAN toe&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. Probeer het IP-adres van het doelapparaat in het bovenste zoekvak in te voeren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>Kan geen samenwerkingsapparaat vinden?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. De mobiele telefoon moet kruis-end samenwerkingssoftware downloaden.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>Ga naar download&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. Na installatie, scant u de code om verbinding te maken met dit apparaat voor samenwerking.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. Na het verbinden van dit apparaat moet het mobiele einde kruis-end samenwerkingssoftware openhouden en op hetzelfde LAN als dit apparaat zijn</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>Handleiding voor gebruik</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>Geen apparaat gevonden</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>Verbind af</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1”toepassen om schermstreaming in te schakelen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>annuleren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>bevestigen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1”verbinding verbroken!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>Weet u zeker dat u verbindt af en samenwerkt met &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>verbind af</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>Overgebleven tijd %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>Code scannen voor verbinding</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>Gebruik aub de kruis-end samenwerkingsapp om de code te scannen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>Mobiele telefoons en apparaten moeten verbonden zijn met hetzelfde lokale netwerk</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>Klik om de UOS-assistent-app te downloaden</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>Bekijken</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>Iedereen in hetzelfde LAN</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>Niet toestaan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>Scherm rechts</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>Scherm links</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Alleen die die samenwerken zijn toegestaan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>Basisinstellingen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>Ontdekmodus</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>Andere apparaten kunnen u ontdekken en verbinden via de &quot;Cooperation&quot; app</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>Apparaatnaam</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>Periferei delen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>Stelt perifereën in die zijn opgesteld om samen te werken over apparaten in staat om dit apparaat te controleren, inclusief toetsenbord, muis, trackpad, etc</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>Wanneer dit apparaat de verbonden partij is, doordringt de muis vanaf het scherm van dit apparaat naar de positie van de verbonden partij</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>Verbindingsrichting</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>Stelt de volgende gebruikers in om bestanden naar mij te sturen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>Locatie voor opslaan van bestanden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>Schermpje delen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>Wanneer het delen op de server (het verbonden apparaat) is ingeschakeld, wordt het schermpje gedeeld tussen de twee computers</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>De apparaatnaam moet 1 tot 20 tekens bevatten</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>De apparaatnaam moet 1 tot 63 tekens bevatten</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>verbinden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>Afdwingen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>Niet in staat om samen te werken met &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>U verbindt met een ander apparaat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>Verzoek om samenwerken met &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation>Coördinatie met &quot;%1&quot; is beëindigd</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation>Een overzijds samenwerkingverzoek is ontvangen van &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>Afwijzen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>Samenwerking</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Verbinding met &quot;%1&quot; is mislukt</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>Niet mogelijk om samen te werken</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>Proces uitvoeren mislukt!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>Verbinding geslaagd, coördineren met &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; heeft uw samenwerkingseis afgewezen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; verbindt met andere apparaten</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>De verbindingseis die &quot;%1&quot; u heeft gestuurd, is onderbroken door een timeout</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>De andere partij bevestigt niet, probeer later opnieuw</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>De andere partij heeft de verbindingseis geannuleerd!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>verbinden mislukt</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>Netwerk niet verbonden, bestandstransmissie mislukt deze keer. Verbind aub met het netwerk en probeer opnieuw!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>Bestandstransmissie mislukt</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>Netwerk niet verbonden, bestandstransmissie mislukt deze keer. Verbind aub met het netwerk en probeer opnieuw!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>Netwerkexclusie</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>Controleer het netwerk &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>Samenwerking</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>Verbinding geslaagd, coördineren met &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Verbinden met &quot;%1&quot; mislukt</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>Bestand lezen/schrijven uitzondering</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>De andere partij heeft de bestandstransmissie geannuleerd</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>Bestand succesvol verzonden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>Bekijk bestandstransmissiegeschiedenis</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>Bestanden verzenden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>De andere partij heeft niet ontvangen, de bestanden zijn niet verzonden</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>Bestand ontvangen %1% | Overgebleven tijd %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>Bestanden verzenden naar &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>Bestanden ontvangen van &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>Afnemen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; stuurt enkele bestanden naar u</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>Bekijk</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>De andere partij heeft de overdrachtsaanvraag geannuleerd !</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>&gt;-
 Onvoldoende opslagruimte, bestandstransmissie is deze keer mislukt. Wis
 aub ruimte op de schijf en probeer opnieuw!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>&gt;-
 Netwerk niet verbonden, bestandstransmissie is deze keer mislukt. Verbind
 aub met het netwerk en probeer opnieuw!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>berekenen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>De andere partij weigert uw aanvraag</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>Verbroken</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>Wacht op bevestiging...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>Voer aub het apparaat-IP/naam van de medewerker in</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>Apparaat in de buurt</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>Herzcanen voor apparaten</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>Bestanden verzenden</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>Bestandsoverdracht</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>Bestandsoverdrachtsinstellingen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>Iedereen in hetzelfde LAN</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Alleen diegene die samenwerken zijn toegestaan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>Niet toestaan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>Sta de volgende gebruikers toe om bestanden naar mij te sturen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>Locatie voor opslag van bestanden</translation>
    </message>
</context>
</TS>